@@ -7,6 +7,11 @@ def Column(primary_key: bool):
     pass
 
 
+def create_all(bind='__all__', app=None):
+    pass
+
+
 class SQLAlchemy(SQLAlchemy):
     Model: Type[Model]
     Column: Column
+    create_all: create_all
